==> avogadro-debuginfo-1.2.0-1.tar.xz: usr/src/debug/avogadro-1.2.0-1/libavogadro/src/tools/qrc_selectrotatetool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-1.x86_64/src/avogadro-1.2.0/libavogadro/src/tools/select.png
  0x0,0x0,0x1,0x1,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0xc,0x0,0x0,0x0,0x15,0x8,0x2,0x0,0x0,0x1,0x8a,0xc9,0xa8,0x75,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,
  0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x6,0x74,0x52,0x4e,0x53,0x0,0xff,0x0,
  0xff,0x0,0xff,0x37,0x58,0x1b,0x7d,0x0,0x0,0x0,0x23,0x74,0x45,0x58,0x74,0x53,
  0x6f,0x66,0x74,0x77,0x61,0x72,0x65,0x0,0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x43,
  0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x28,0x50,0x6f,0x77,0x65,0x72,0x50,
  0x43,0x29,0xb6,0xa6,0x73,0xa1,0x0,0x0,0x0,0x72,0x49,0x44,0x41,0x54,0x78,0x9c,
  0x94,0x91,0xdb,0x11,0xc0,0x20,0x8,0x4,0xaf,0x34,0xfa,0x6f,0x8a,0x64,0x32,0x8c,
  0x72,0xbc,0x34,0x7c,0x9,0x2c,0xba,0x2a,0x0,0xa8,0x2a,0x2c,0x44,0x4,0xae,0xb2,
  0x3b,0xbc,0xd2,0x2f,0x2c,0x8b,0x49,0x37,0x41,0xb3,0xd4,0x8d,0x25,0xdf,0x40,0x1d,
  0x26,0xba,0xa8,0xb0,0x5,0x95,0xa,0xc7,0x3b,0x89,0x3f,0x5e,0x54,0x7a,0xed,0xe8,
  0xc4,0x42,0xf5,0xda,0x7e,0x6d,0x57,0xa8,0xd6,0x57,0xcc,0xfe,0x13,0xd4,0xa1,0xcd,
  0xc3,0xf,0x1f,0xd6,0xa1,0x7,0x8,0xee,0x37,0xf,0x5a,0xc6,0xe6,0xe3,0x9,0x1a,
  0xee,0x32,0x41,0x99,0x7b,0x0,0x0,0x0,0xff,0xff,0x3,0x0,0x2,0x84,0x86,0xd,
  0x97,0xf,0xeb,0xc7,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
  
};

static const unsigned char qt_resource_name[] = {
  // select
  0x0,0x6,
  0x7,0x9c,0x2b,0xa4,
  0x0,0x73,
  0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x63,0x0,0x74,
    // select.png
  0x0,0xa,
  0xb,0xa8,0x6f,0x7,
  0x0,0x73,
  0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/select
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/select/select.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_selectrotatetool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_selectrotatetool))

int QT_MANGLE_NAMESPACE(qCleanupResources_selectrotatetool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_selectrotatetool))

==> avogadro-debuginfo-1.2.0-2.tar.xz: usr/src/debug/avogadro-1.2.0-2/libavogadro/src/tools/qrc_selectrotatetool.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/avogadro/avogadro-1.2.0-2.i686/src/avogadro-1.2.0/libavogadro/src/tools/select.png
  0x0,0x0,0x1,0x1,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0xc,0x0,0x0,0x0,0x15,0x8,0x2,0x0,0x0,0x1,0x8a,0xc9,0xa8,0x75,
  0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x13,0x0,0x0,0xb,0x13,
  0x1,0x0,0x9a,0x9c,0x18,0x0,0x0,0x0,0x6,0x74,0x52,0x4e,0x53,0x0,0xff,0x0,
  0xff,0x0,0xff,0x37,0x58,0x1b,0x7d,0x0,0x0,0x0,0x23,0x74,0x45,0x58,0x74,0x53,
  0x6f,0x66,0x74,0x77,0x61,0x72,0x65,0x0,0x47,0x72,0x61,0x70,0x68,0x69,0x63,0x43,
  0x6f,0x6e,0x76,0x65,0x72,0x74,0x65,0x72,0x20,0x28,0x50,0x6f,0x77,0x65,0x72,0x50,
  0x43,0x29,0xb6,0xa6,0x73,0xa1,0x0,0x0,0x0,0x72,0x49,0x44,0x41,0x54,0x78,0x9c,
  0x94,0x91,0xdb,0x11,0xc0,0x20,0x8,0x4,0xaf,0x34,0xfa,0x6f,0x8a,0x64,0x32,0x8c,
  0x72,0xbc,0x34,0x7c,0x9,0x2c,0xba,0x2a,0x0,0xa8,0x2a,0x2c,0x44,0x4,0xae,0xb2,
  0x3b,0xbc,0xd2,0x2f,0x2c,0x8b,0x49,0x37,0x41,0xb3,0xd4,0x8d,0x25,0xdf,0x40,0x1d,
  0x26,0xba,0xa8,0xb0,0x5,0x95,0xa,0xc7,0x3b,0x89,0x3f,0x5e,0x54,0x7a,0xed,0xe8,
  0xc4,0x42,0xf5,0xda,0x7e,0x6d,0x57,0xa8,0xd6,0x57,0xcc,0xfe,0x13,0xd4,0xa1,0xcd,
  0xc3,0xf,0x1f,0xd6,0xa1,0x7,0x8,0xee,0x37,0xf,0x5a,0xc6,0xe6,0xe3,0x9,0x1a,
  0xee,0x32,0x41,0x99,0x7b,0x0,0x0,0x0,0xff,0xff,0x3,0x0,0x2,0x84,0x86,0xd,
  0x97,0xf,0xeb,0xc7,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
  
};

static const unsigned char qt_resource_name[] = {
  // select
  0x0,0x6,
  0x7,0x9c,0x2b,0xa4,
  0x0,0x73,
  0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x63,0x0,0x74,
    // select.png
  0x0,0xa,
  0xb,0xa8,0x6f,0x7,
  0x0,0x73,
  0x0,0x65,0x0,0x6c,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/select
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/select/select.png
  0x0,0x0,0x0,0x12,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_selectrotatetool)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_selectrotatetool))

int QT_MANGLE_NAMESPACE(qCleanupResources_selectrotatetool)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_selectrotatetool))
